Package: deckglgeoarrow
Title: Use 'GeoArrow' to Add 'Deck.gl' Layers to a
        'maplibregl'/'mapboxgl' Map
Version: 0.0.2
Authors@R: 
    c(person(given = "Tim",
             family = "Appelhans",
             role = c("cre", "aut"),
             email = "tappelhans@tutamail.com",
             comment = c(ORCID = "0000-0002-9824-2707")),
      person("RConsortium", 
             role = "fnd",
             comment = c("https://r-consortium.org/", ROR = "01z833950")))
Description: Leverages the high-performance 'GeoArrow' memory layout to render
    potentially very large 'Deck.gl' data layers on a 'maplibregl'/'mapboxgl' 
    map created with R package 'mapgl'. The heavy lifting is done on the 
    'JavaScript' side in the browser using 'deck.gl-geoarrow' 
    (<https://github.com/geoarrow/deck.gl-geoarrow/>). 
    Currently provides functions for adding Scatterplot (points), Path (lines)
    and Polygon (polygons) layers. Has support for data classes from R packages 
    'wk' and 'sf'. In addition, convenience functions for styling data, tooltips 
    and popups, as well as layer management are provided. 
    Furthermore, remotely hosted 'GeoParquet' and 'GeoArrow' files can be 
    visualised directly in the browser, without the need to first read them 
    into R memory. Only the styling instructions are prepared by the user in R 
    and are then transferred to and applied in the browser as the data arrives.
License: MIT + file LICENSE
Depends: R (>= 4.1.0)
Imports: geoarrow, geoarrowWidget, htmltools, htmlwidgets, nanoarrow,
Suggests: geos, mapgl, quarto, terra, tinytest, wk
VignetteBuilder: quarto
Encoding: UTF-8
RoxygenNote: 7.3.3
URL: https://github.com/r-spatial/deckglgeoarrow,
        https://r-spatial.github.io/deckglgeoarrow/
BugReports: https://github.com/r-spatial/deckglgeoarrow/issues
SystemRequirements: Quarto command line tool
        (<https://github.com/quarto-dev/quarto-cli>).
NeedsCompilation: no
Packaged: 2026-07-01 09:55:38 UTC; tim
Author: Tim Appelhans [cre, aut] (ORCID:
    <https://orcid.org/0000-0002-9824-2707>),
  RConsortium [fnd] (https://r-consortium.org/, ROR:
    <https://ror.org/01z833950>)
Maintainer: Tim Appelhans <tappelhans@tutamail.com>
Repository: CRAN
Date/Publication: 2026-07-06 14:30:12 UTC
Built: R 4.6.1; ; 2026-07-06 19:22:03 UTC; unix
