# Generated by roxygen2: do not edit by hand

S3method(addGeoArrowPathLayer,mapboxgl)
S3method(addGeoArrowPathLayer,maplibregl)
S3method(addGeoArrowPointCloudLayer,mapboxgl)
S3method(addGeoArrowPointCloudLayer,maplibregl)
S3method(addGeoArrowPolygonLayer,mapboxgl)
S3method(addGeoArrowPolygonLayer,maplibregl)
S3method(addGeoArrowScatterplotLayer,mapboxgl)
S3method(addGeoArrowScatterplotLayer,maplibregl)
export(addGeoArrowPathLayer)
export(addGeoArrowPolygonLayer)
export(addGeoArrowScatterplotLayer)
export(dataAccessors)
export(extJSLibs)
export(generateDeckglLayerId)
export(popupOptions)
export(renderOptions)
export(tooltipOptions)
